import React, { useEffect, useState } from "react";
import { connect } from "react-redux";
import { Row, Col, Container, Button } from "react-bootstrap";
import LanguageText from "components/common/languageText";
import SliderDataAccess from "dataAccess/sliderDataAccess";
import ProductDataAccess from "dataAccess/productDataAccess";
import { Link } from "react-router-dom";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faFacebook, faFacebookF} from "@fortawesome/free-brands-svg-icons";

const Footer = (props: any) => {
  const [emailOne, setEmailOne] = useState(null);
  const [emailTwo, setEmailTwo] = useState(null);
  const [companyName, setCompanyName] = useState(null);
  const [phoneOne, setPhoneOne] = useState(null);
  const [phoneTwo, setPhoneTwo] = useState(null);
  const [phoneThree, setPhoneThree] = useState(null);
  const [address, setAddress] = useState(null);

  const [aboutData, setAboutData] = useState([]);

  useEffect(() => {
    SliderDataAccess.getAboutData()
      .then((data) => {
        setAboutData(data.data.abouts);
      })
      .catch((error) => {});
  }, []);

  const [shopStickStoreProducts, setShopStickStoreProducts] = useState([]);

  useEffect(() => {
    SliderDataAccess.getSectionData()
      .then((data) => {
        setShopStickStoreProducts(data.data.sections);
      })
      .catch((error) => {});
  }, []);

  // useEffect(() => {
  //   ProductDataAccess.getHomePageAllCardData()
  //     .then((data) => {
  //       console.log(data);
  //       setShopStickStoreProducts(data);
  //     })
  //     .catch((error) => {});
  // }, []);

  useEffect(() => {
    SliderDataAccess.getSettingData()
      .then((data) => {
        setAddress(data.address);
        setEmailOne(data.primary_email);
        setEmailTwo(data.email2);
        setPhoneOne(data.primary_phone);
        setPhoneTwo(data.phone2);
        setPhoneThree(data.phone3);
        setCompanyName(data.company_name);
      })
      .catch((error) => {});
  }, []);

  return (
    <footer className="footer-container">
      <Container>
        <Row>
          <Col sm={6} md={6} lg={3} xl={3}>
            <div>
              <p className="title">
                {" "}
                <LanguageText firstKey="footer" secondKey="myProfile" />{" "}
              </p>
              <div>
                <Link to="/my-profile">
                  {" "}
                  <div className="menu-item">Personal Info</div>{" "}
                </Link>
                <Link to="/change-password">
                  {" "}
                  <div className="menu-item">Change password</div>{" "}
                </Link>
                <Link to="/orders">
                  {" "}
                  <div className="menu-item">Orders</div>{" "}
                </Link>
                <Link to="/user-reviews-all">
                  {" "}
                  <div className="menu-item">Reviews</div>{" "}
                </Link>
                <Link to="/coupons">
                  {" "}
                  <div className="menu-item">Coupons</div>{" "}
                </Link>
                <Link to="/address">
                  {" "}
                  <div className="menu-item">Address</div>{" "}
                </Link>
              </div>
            </div>
          </Col>
          <Col sm={6} md={6} lg={3} xl={3}>
            <div className="">
              <p className="title">
                {" "}
                About {companyName}
                {/* <LanguageText
                  firstKey="footer"
                  secondKey={"about" + companyName}
                />{" "} */}
              </p>
              <div>
                {aboutData.length !== 0 &&
                  aboutData.map((single, index) => (
                    <Link to={'/about/' + single.id} key={index}>
                      {" "}
                      <div className="menu-item">{single.en_title}</div>{" "}
                    </Link>
                  ))}
              </div>
              {/* <div>
                <Link to="/what-we-are">
                  {" "}
                  <div className="menu-item">What we are?</div>{" "}
                </Link>
                <Link to="/our-services">
                  {" "}
                  <div className="menu-item">Our services</div>{" "}
                </Link>
                <Link to="/terms-of-services">
                  {" "}
                  <div className="menu-item">Terms of service</div>{" "}
                </Link>
                <Link to="/faq">
                  {" "}
                  <div className="menu-item">Help & FAQ</div>{" "}
                </Link>
                <Link to="/return-and-refund">
                  {" "}
                  <div className="menu-item">Return & Refund</div>{" "}
                </Link>
              </div> */}
            </div>
          </Col>
          <Col sm={6} md={6} lg={3} xl={3}>
            <div className="">
              <p className="title">
                {" "}
                <LanguageText firstKey="footer" secondKey="haveAlook" />{" "}
              </p>
              <div>
                {shopStickStoreProducts?.map((singleProduct, index) => (
                    <Link to={`/all-products/${singleProduct.en_name}`}>
                      {" "}
                      <div className="menu-item">
                        {singleProduct.en_name}
                      </div>{" "}
                    </Link>
                  ))}
                {/* <Link to="/our-offers">
                  {" "}
                  <div className="menu-item">Our offers</div>{" "}
                </Link>
                <Link to="#">
                  {" "}
                  <div className="menu-item">New arrivals</div>{" "}
                </Link>
                <Link to="#">
                  {" "}
                  <div className="menu-item">Hot deals</div>{" "}
                </Link>
                <Link to="#">
                  {" "}
                  <div className="menu-item">Summer collections</div>{" "}
                </Link>
                <Link to="#">
                  {" "}
                  <div className="menu-item">Eid collections</div>{" "}
                </Link> */}
              </div>
            </div>
          </Col>
          <Col sm={6} md={6} lg={3} xl={3}>
            <div className="contact-info-container">
              <p className="title">
                {" "}
                <LanguageText firstKey="footer" secondKey="contactInfo" />{" "}
              </p>
              <div>
                <div className="area">
                  <div>
                    <img alt="mail" src="/images/mail.png" />
                    {emailOne !== null ? (
                      <span className="menu-item-contact">{emailOne}</span>
                    ) : (
                      <span className="menu-item-contact"></span>
                    )}
                  </div>
                  <div>
                    <img alt="mail" src="/images/mail.png" />
                    {emailTwo !== null ? (
                      <span className="menu-item-contact">{emailTwo}</span>
                    ) : (
                      <span className="menu-item-contact"></span>
                    )}
                  </div>
                </div>
                <div className="area">
                  <div>
                    <img alt="mail" src="/images/phone.png" />
                    {phoneOne !== null ? (
                      <span className="menu-item-contact">{phoneOne}</span>
                    ) : (
                      <span className="menu-item-contact"></span>
                    )}
                  </div>
                  <div>
                    <img alt="mail" src="/images/phone.png" />
                    {phoneTwo !== null ? (
                      <span className="menu-item-contact">{phoneTwo}</span>
                    ) : (
                      <span className="menu-item-contact"></span>
                    )}
                  </div>
                  <div>
                    <img alt="mail" src="/images/phone.png" />
                    {phoneThree !== null ? (
                      <span className="menu-item-contact">{phoneThree}</span>
                    ) : (
                      <span className="menu-item-contact"></span>
                    )}
                  </div>
                  {/* <div>
                    <span className="menu-item-contact">+88 01923 199 199</span>
                  </div>
                  <div>
                    <span className="menu-item-contact">+88 01923 211 211</span>
                  </div> */}
                </div>
                {address !== null ? (
                  <div className="area">
                    <div>
                      <img alt="mail" src="/images/map-pin.png" />
                      <span className="menu-item-contact">{address}</span>
                    </div>
                    {/* <div>
                    <span className="menu-item-contact">
                      Sonadanga, Khulna, Bangladesh{" "}
                    </span>
                  </div> */}
                  </div>
                ) : (
                  <div className="area">
                    <div>
                      <img alt="mail" src="/images/map-pin.png" />
                      <span className="menu-item-contact">
                        Road: Sonadanga Main Road,
                      </span>
                    </div>
                    <div>
                      <span className="menu-item-contact">
                        Sonadanga, Khulna, Bangladesh{" "}
                      </span>
                    </div>
                  </div>
                )}
              </div>
            </div>
          </Col>
        </Row>
        <Row>
          <Col>
            <div className="social-row">
              <Link to="/contact-us">
                {" "}
                <Button className="rounded-pill" variant="outline-primary">
                  {" "}
                  Email Us{" "}
                </Button>{" "}
              </Link>{" "}
              &nbsp;
              <span>
                {" "}
                <a target="_blank" href="https://www.facebook.com/GenxSys">
                     <i className="fab fa-facebook fa-lg ml-3" style={{color: '#fff', marginRight: 12}}/>
                </a>
              </span>{" "}
              <span>
                {" "}
                <a target="_blank" href="https://www.instagram.com/genx_system">
                     <i className="fab fa-instagram fa-lg" style={{color: '#fff', marginRight: 12}}/>
                </a>
              </span>{" "}
              <span>
                {" "}
                <a target="_blank" href="https://www.youtube.com/watch?v=zh1U92jgl0c">
                     <i className="fab fa-youtube fa-lg" style={{color: '#fff', marginRight: 12}}/>
                </a>
              </span>{" "}
              <span>
                {" "}
                <a target="_blank" href="https://in.linkedin.com/company/genx-systems">
                     <i className="fab fa-linkedin fa-lg" style={{color: '#fff', marginRight: 12}}/>
                </a>
              </span>{" "}
              {/*&nbsp;*/}
              {/*<img alt="mail" src="/images/in.png" />*/}
              {/*&nbsp;*/}
              {/*<img alt="mail" src="/images/tw.png" />*/}
              {/*&nbsp;*/}
              {/*<img alt="mail" src="/images/yt.png" />*/}
            </div>
          </Col>
        </Row>
      </Container>

      <div className="copyright">
        <div className="container">
          <div className="row copyright-text">
            <div className="col-lg-12">
              <p className="p-small">
                © 2021 &nbsp;
                <span style={{ color: "white" }}>www.genx.ae.</span>&nbsp;
                <span style={{ color: "#40BFFF" }}></span>All rights reserved.
              </p>
            </div>
          </div>
        </div>
      </div>
    </footer>
  );
};

const mapStateToProps = (state) => ({});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(Footer);
